@@ -1,14 +1,14 @@
 package Workflow::History;
 
-# $Id: History.pm 361 2008-04-05 13:23:31Z jonasbn $
+# $Id: History.pm,v 1.7 2004/05/14 05:13:52 cwinters Exp $
 
 use strict;
 use base qw( Class::Accessor );
 use DateTime;
 
-$Workflow::History::VERSION = '1.09';
+$Workflow::History::VERSION  = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
-my @FIELDS = qw( id workflow_id action description date user state time_zone );
+my @FIELDS = qw( id workflow_id action description date user state );
 __PACKAGE__->mk_accessors( @FIELDS );
 
 sub new {
@@ -17,23 +17,12 @@ sub new {
     for ( @FIELDS ) {
         $self->$_( $params->{ $_ } ) if ( $params->{ $_ } );
     }
-
-    my $time_zone = exists $params->{time_zone} ? $params->{time_zone} : 'floating';
-    $self->time_zone($time_zone);
-
     unless ( $self->date ) {
-        $self->date( DateTime->now(time_zone => $self->time_zone()) );
+        $self->date( DateTime->now() );
     }
     return $self;
 }
 
-sub set_new_state {
-    my ( $self, $new_state ) = @_;
-    unless ( $self->state ) {
-        $self->state( $new_state );
-    }
-}
-
 sub is_saved {
     my ( $self ) = @_;
     return $self->{_saved};
@@ -88,32 +77,12 @@ about how the history is saved, just that the history is available.
 
 =head2 Public Methods
 
-=head3 new( \%params )
+B<new( \%params )>
 
 Create a new history object, filling it with properties from
 C<\%params>.
 
-=head3 set_new_state( $new_state )
-
-Assigns the new state C<$new_state> to the history if the state is not
-already assigned. This is used when you generate a history request in
-a L<Workflow::Action> since the workflow state will change once the
-action has successfully completed. So in the action you create a
-history object without the state:
-
-  $wf->add_history(
-      Workflow::History->new({
-          action      => "Cocoa Puffs",
-          description => "They're magically delicious",
-          user        => "Count Chocula",
-      })
-  );
-
-And then after the new state has been set but before the history
-objects are stored the workflow sets the new state in all unsaved
-history objects.
-
-=head3 is_saved()
+B<is_saved()>
 
 Returns true if this history object has been saved, false if not.
 
@@ -143,10 +112,6 @@ B<date> - Date history noted, set to a L<DateTime> object.
 
 =item *
 
-B<time_zone> - Time zone to pass to the L<DateTime> object.
-
-=item *
-
 B<user> - User name (ID, login, or full name, up to you) taking action
 (may be blank)
 
@@ -156,29 +121,17 @@ B<state> - State of workflow as history was recorded.
 
 =back
 
-=head3 clear_saved
-
-Sets saved state to false and returns 0
-
-=head3 set_saved
-
-Sets saved state to true and returns 1
-
 =head1 SEE ALSO
 
 L<Workflow>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
 Chris Winters E<lt>chris@cwinters.comE<gt>
-
-=cut
